==> un-applet_1.4_all.tar.bz2: un-applet_1.4_all/usr/share/un-applet/popup.py <==
# -*- coding: utf-8 -*-

import Tkinter
from Icon import Icon

class PopupNotification(Tkinter.Toplevel):
    def __init__(self, master, icon=None, message='', detail='', duration=5000,
                    relief='groove', bd=2, **kw):
        Tkinter.Toplevel.__init__(self, master, relief=relief, bd=bd, **kw)
        self.withdraw()
        self.overrideredirect(1)
        self.bind('<ButtonRelease-1>', self.hide)
        self._duration = duration

        self.img = Icon(icon)
        self.icon = Tkinter.Label(self, image=self.img)
        self.icon.grid(row=0, column=0, rowspan=2, padx=10, pady=5)
        self.message = Tkinter.Label(self, text=message, font='TkCaptionFont')
        self.message.grid(row=0, column=1, pady=(5, 3), padx=10)
        self.detail = Tkinter.Label(self, text=detail)
        self.detail.grid(row=1, column=1, pady=(3, 5), padx=10)
        self.update_idletasks()

        self._orient = master.orientation()
        if not self._orient in ('horizontal', 'vertical'):
            # might be "unknown" or maybe even something diffferent(?);
            # if orientation is unknown, stick with the most likely thing
            self._orient = 'horizontal'
        x0, y0, x1, y1 = master.bbox()

        sh, sw = self.winfo_screenheight(), self.winfo_screenwidth()
        self._maxheight, self._maxwidth = self.winfo_reqheight(), self.winfo_reqwidth()
        if self._orient == 'horizontal':
            self._height = 0
            self._width = self._maxwidth
        else:
            self._height = self._maxheight
            self._width = 0

        if self._orient == 'horizontal':
            if y0 < (sh / 2):
                self._traypos = 'top'
                self.y = y1
            else:
                self._traypos = 'bottom'
                self.y = y0
            self.x = x0 + (x1 - x0) / 2 - self._width / 2
            if self.x < 0:
                self.x = 0
            elif self.x + self._width > sw:
                self.x = sw - self._width
        else:
            if x0 < (sw / 2):
                self._traypos = 'left'
                self.x = x1
            else:
                self._traypos = 'right'
                self.x = x0
            self.y = y0 + (y1 - y0) / 2 - self._height / 2
            if self.y < 0:
                self.y = 0
            elif self.y + self._height > sh:
                self.y = sh - self._height

        self.update_geometry()
        self.deiconify()
        self._id = self.after(50, self.grow)

    def grow(self):
        if self._orient == 'horizontal':
            if self._height < self._maxheight:
                self._height += 1
                self.update_geometry()
                self._id = self.after(50, self.grow)
            else:
                self._id = self.after(self._duration, self.shrink)
        else:
            if self._width < self._maxwidth:
                self._width += 3
                if self._width > self._maxwidth:
                    self._width = self._maxwidth
                self.update_geometry()
                self._id = self.after(50, self.grow)
            else:
                self._id = self.after(self._duration, self.shrink)

    def hide(self, *event):
        if not self._id is None:
            _id = self._id
            self._id = None
            self.after_cancel(_id)
        self.destroy()

    def shrink(self):
        if self._orient == 'horizontal':
            if self._height > 0:
                self._height -= 1
                self.update_geometry()
                self._id = self.after(50, self.shrink)
            else:
                self.destroy()
        else:
            if self._width > 0:
                self._width -= 3
                if self._width < 0:
                    self._width = 0
                self.update_geometry()
                self._id = self.after(50, self.shrink)
            else:
                self.destroy()

    def update_geometry(self):
        if self._traypos == 'bottom':
            self.geometry('%dx%d+%d+%d' % (
                    self._width, self._height, self.x, self.y - self._height))
        elif self._traypos == 'right':
            self.geometry('%dx%d+%d+%d' % (
                    self._width, self._height, self.x - self._width, self.y))
        else:
            self.geometry('%dx%d+%d+%d' % (
                    self._width, self._height, self.x, self.y))

==> un-applet_1.5_all.tar.bz2: un-applet_1.5_all/usr/share/un-applet/popup.py <==
# -*- coding: utf-8 -*-

import Tkinter
from Icon import Icon

class PopupNotification(Tkinter.Toplevel):
    def __init__(self, master, icon=None, message='', detail='', duration=5000,
                    animate=1, fixedpos=0, relief='groove', bd=2, **kw):
        Tkinter.Toplevel.__init__(self, master, relief=relief, bd=bd, **kw)
        self.withdraw()
        self.overrideredirect(1)
        self.bind('<ButtonRelease-1>', self.hide)
        self._duration = duration
        self._fixedpos = fixedpos

        self.img = Icon(icon)
        self.icon = Tkinter.Label(self, image=self.img)
        self.icon.grid(row=0, column=0, rowspan=2, padx=10, pady=5)
        self.message = Tkinter.Label(self, text=message, font='TkCaptionFont')
        self.message.grid(row=0, column=1, pady=(5, 3), padx=10)
        self.detail = Tkinter.Label(self, text=detail)
        self.detail.grid(row=1, column=1, pady=(3, 5), padx=10)
        self.update_idletasks()

        self._orient = master.orientation()
        if not self._orient in ('horizontal', 'vertical'):
            # might be "unknown" or maybe even something diffferent(?);
            # if orientation is unknown, stick with the most likely thing
            self._orient = 'horizontal'
        x0, y0, x1, y1 = master.bbox()

        sh, sw = self.winfo_screenheight(), self.winfo_screenwidth()
        self._maxheight, self._maxwidth = self.winfo_reqheight(), self.winfo_reqwidth()

        if animate:
            if self._orient == 'horizontal':
                self._height = 0
                self._width = self._maxwidth
            else:
                self._height = self._maxheight
                self._width = 0
        else:
            self._height = self._maxheight
            self._width = self._maxwidth

        if fixedpos:
            # put balloon in the upper right screen corner
            self.x = sw - self._width - 30
            self.y = 30
            self._traypos = 'top'
        else:
            if self._orient == 'horizontal':
                if y0 < (sh / 2):
                    self._traypos = 'top'
                    self.y = y1
                else:
                    self._traypos = 'bottom'
                    self.y = y0
                self.x = x0 + (x1 - x0) / 2 - self._width / 2
                if self.x < 0:
                    self.x = 0
                elif self.x + self._width > sw:
                    self.x = sw - self._width
            else:
                if x0 < (sw / 2):
                    self._traypos = 'left'
                    self.x = x1
                else:
                    self._traypos = 'right'
                    self.x = x0
                self.y = y0 + (y1 - y0) / 2 - self._height / 2
                if self.y < 0:
                    self.y = 0
                elif self.y + self._height > sh:
                    self.y = sh - self._height

        self.update_geometry()
        self.deiconify()
        if animate:
            self._id = self.after(50, self.grow)
        else:
            self._id = self.after(duration, self.destroy)

    def grow(self):
        if self._orient == 'horizontal':
            if self._height < self._maxheight:
                self._height += 1
                self.update_geometry()
                self._id = self.after(50, self.grow)
            else:
                self._id = self.after(self._duration, self.shrink)
        else:
            if self._width < self._maxwidth:
                self._width += 3
                if self._width > self._maxwidth:
                    self._width = self._maxwidth
                self.update_geometry()
                self._id = self.after(50, self.grow)
            else:
                self._id = self.after(self._duration, self.shrink)

    def hide(self, *event):
        if not self._id is None:
            _id = self._id
            self._id = None
            self.after_cancel(_id)
        self.destroy()

    def shrink(self):
        if self._orient == 'horizontal':
            if self._height > 0:
                self._height -= 1
                self.update_geometry()
                self._id = self.after(50, self.shrink)
            else:
                self.destroy()
        else:
            if self._width > 0:
                self._width -= 3
                if self._width < 0:
                    self._width = 0
                self.update_geometry()
                self._id = self.after(50, self.shrink)
            else:
                self.destroy()

    def update_geometry(self):
        if self._traypos == 'bottom':
            self.geometry('%dx%d+%d+%d' % (
                    self._width, self._height, self.x, self.y - self._height))
        elif self._traypos == 'right':
            self.geometry('%dx%d+%d+%d' % (
                    self._width, self._height, self.x - self._width, self.y))
        else:
            self.geometry('%dx%d+%d+%d' % (
                    self._width, self._height, self.x, self.y))
